@@ -39,6 +39,8 @@
  *
  */
 
+#define _BSD_SOURCE
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -940,7 +942,7 @@ void tinyjpeg_get_size(struct jdec_private *priv, unsigned int *width, unsigned
 int tinyjpeg_get_components(struct jdec_private *priv, unsigned char **components)
 {
   int i;
-  for (i=0; priv->components[i] && i<COMPONENTS; i++)
+  for (i=0; i<COMPONENTS && priv->components[i]; i++)
     components[i] = priv->components[i];
   return 0;
 }
