@@ -21,6 +21,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#define _BSD_SOURCE
+
 #include "config.h"
 
 #include <stdio.h>
@@ -32,8 +34,8 @@
 #ifdef OS2
 #include <db.h>
 #endif
-#include <netinet/in.h>
 
+#include "gphoto2-endian.h"
 #include "digita.h"
 
 #define GP_MODULE "digita"
