@@ -4,15 +4,17 @@
        Hubert Figuiere <hfiguiere@teaser.fr>
  */
 
+#define _POSIX_C_SOURCE 199309L
+
 #include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#include <gphoto2.h>
-#include <gphoto2-port.h>
-#include <gphoto2-endian.h>
+#include <gphoto2/gphoto2.h>
+#include <gphoto2/gphoto2-port.h>
+#include "gphoto2-endian.h"
 
 #include "dc240.h"
 #include "library.h"
@@ -42,17 +44,17 @@
 
 /* legacy from dc240.h */
 /*
-  #define COMM1	(unsigned char)0x00
-  #define READY	(unsigned char)0x10
-  #define ACK	(unsigned char)0xd1
-  #define PACK1	(unsigned char)0xd2
+  #define COMM1	0x00
+  #define READY	0x10
+  #define ACK	0xd1
+  #define PACK1	0xd2
 */
 /* nice. errors all have upper nibble of 'e' */
 /*
-  #define	NAK	(unsigned char)0xe1
-  #define	COMM0	(unsigned char)0xe2
-  #define PACK0	(unsigned char)0xe3
-  #define CANCL	(unsigned char)0xe4
+  #define NAK	0xe1
+  #define COMM0	0xe2
+  #define PACK0	0xe3
+  #define CANCL	0xe4
 */
 
 /* system codes */
@@ -68,33 +70,31 @@ enum {
     DC240_SC_BUSY = 0xf0
 };
 
-static char *dc240_packet_new   (int command_byte);
-static int   dc240_packet_write (Camera *camera, char *packet, int size,
+static unsigned char *dc240_packet_new   (int command_byte);
+static int   dc240_packet_write (Camera *camera, unsigned char *packet, int size,
 				 int read_response);
-static int   dc240_packet_read  (Camera *camera, char *packet, int size);
+static int   dc240_packet_read  (Camera *camera, unsigned char *packet, int size);
 
 
 
-static char *dc240_packet_new (int command_byte) {
-
-    char *p = (char *)malloc(sizeof(char) * 8);
+static unsigned char *
+dc240_packet_new (int command_byte) {
 
+    unsigned char *p = malloc(8);
     memset (p, 0, 8);
-
     p[0] = command_byte;
     p[7] = 0x1a;
-
     return p;
 }
 
-static char *dc240_packet_new_path (const char *folder, const char *filename) {
-
-    char *p;
+static unsigned char *
+dc240_packet_new_path (const char *folder, const char *filename) {
+    unsigned char *p;
     char buf[1024];
     int x;
     unsigned char cs = 0;
 
-    p = (char *)malloc(sizeof(char)*60);
+    p = malloc(sizeof(char)*60);
     if (!p)
         return NULL;
 
@@ -117,12 +117,11 @@ static char *dc240_packet_new_path (const char *folder, const char *filename) {
     p[0] = 0x80;
     memcpy(&p[1], buf, sizeof(char)*strlen(buf));
     p[59] = cs;
-
     return (p);
 }
 
 
-static int dc240_packet_write (Camera *camera, char *packet, int size, int read_response) {
+static int dc240_packet_write (Camera *camera, unsigned char *packet, int size, int read_response) {
 
     /* Writes the packet and returns the result */
 
@@ -141,7 +140,7 @@ write_again:
         return (GP_ERROR_TIMEOUT);
     }
 
-    if (gp_port_write(camera->port, packet, size) < GP_OK) {
+    if (gp_port_write(camera->port, (char*)packet, size) < GP_OK) {
         goto write_again;
     }
 
@@ -157,10 +156,10 @@ write_again:
 }
 
 static int
-dc240_packet_read (Camera *camera, char *packet, int size)
+dc240_packet_read (Camera *camera, unsigned char *packet, int size)
 {
 
-    int retval = gp_port_read(camera->port, packet, size);
+    int retval = gp_port_read(camera->port, (char*)packet, size);
 
     /*
      * If we try to read data about a non-picture file, we get back
@@ -168,16 +167,13 @@ dc240_packet_read (Camera *camera, char *packet, int size)
      * size greater than one, but we only get one byte, and it is a
      * DC240_SC_ERROR error, return failure
      */
-    if ((size > 1) && (retval == 1) && ((unsigned char)packet[0] == DC240_SC_ERROR)) {
+    if ((size > 1) && (retval == 1) && (packet[0] == DC240_SC_ERROR))
 	return GP_ERROR_NOT_SUPPORTED;
-    }
 
-    if (retval < GP_OK) {
+    if (retval < GP_OK)
 	return retval;
-    }
-    else {
+    else
 	return GP_OK;
-    }
 }
 
 static int dc240_packet_write_ack (Camera *camera)
@@ -186,7 +182,7 @@ static int dc240_packet_write_ack (Camera *camera)
     unsigned char c;
 
     c = DC240_SC_CORRECT;
-    retval = gp_port_write(camera->port, &c, 1);
+    retval = gp_port_write(camera->port, (char*)&c, 1);
     if (retval < GP_OK)
 	return retval;
     return GP_OK;
@@ -198,15 +194,14 @@ static int dc240_packet_write_nak (Camera *camera)
     unsigned char c;
 
     c = DC240_SC_ILLEGAL;
-    retval = gp_port_write(camera->port, &c, 1);
+    retval = gp_port_write(camera->port, (char*)&c, 1);
     if (retval < GP_OK)
 	return retval;
     return GP_OK;
 }
 
 static int dc240_wait_for_completion (Camera *camera) {
-
-    char p[8];
+    unsigned char p[8];
     int retval = GP_OK;
     int x=0, done=0;
 
@@ -243,7 +238,7 @@ static int dc240_wait_for_busy_completion (Camera *camera)
     enum {
 	BUSY_RETRIES = 100
     };
-    char p[8];
+    unsigned char p[8];
     int retval;
     int x=0, done=0;
 
@@ -259,30 +254,28 @@ static int dc240_wait_for_busy_completion (Camera *camera)
 	    /* in busy state, GP_ERROR_IO_READ can happend */
 	    break;
 	default:
-	    if (*p != (char)DC240_SC_BUSY) {
+	    if (*p != DC240_SC_BUSY) {
 		done = 1;
 	    }
 	}
     }
-
     if (x == BUSY_RETRIES)
 	return (GP_ERROR);
-
     return retval;
 }
 
 
 static int dc240_packet_exchange (Camera *camera, CameraFile *file,
-                           char *cmd_packet, char *path_packet,
+                           unsigned char *cmd_packet, unsigned char *path_packet,
                            int *size, int block_size, GPContext *context)
 {
     /* Reads in multi-packet data, appending it to the "file". */
-    char check_sum;
+    unsigned char check_sum;
     int i;
     int num_packets=1, num_bytes, retval = GP_OK;
     int x=0, retries=0;
     float t;
-    char packet[HPBS+2];
+    unsigned char packet[HPBS+2];
     unsigned int id;
 
     if (*size > 0) {
@@ -301,16 +294,14 @@ read_data_write_again:
     /* Write command/path packets */
     if (cmd_packet) {
 	retval = dc240_packet_write(camera, cmd_packet, 8, 1);
-        if (retval < GP_OK) {
+        if (retval < GP_OK)
             return retval;
-	}
     }
 
     if (path_packet) {
 	retval = dc240_packet_write(camera, path_packet, 60, 1);
-        if (retval < GP_OK) {
+        if (retval < GP_OK)
             return retval;
-	}
     }
 
     id = gp_context_progress_start (context, num_packets, _("Getting data..."));
@@ -321,9 +312,8 @@ read_data_read_again:
         /* Read the response/data */
         retval = dc240_packet_read(camera, packet, block_size+2);
 
-	if (retval == GP_ERROR_NOT_SUPPORTED) {
+	if (retval == GP_ERROR_NOT_SUPPORTED)
 	    return retval;
-	}
 
         if ((retval == GP_ERROR) || (retval == GP_ERROR_TIMEOUT)) {
             /* ERROR reading response/data */
@@ -353,13 +343,13 @@ read_data_read_again:
 	}
 
         /* Check for error in command/path */
-        if ((unsigned char)packet[0] > DC240_SC_FIRST_ERROR) {
+        if (packet[0] > DC240_SC_FIRST_ERROR) {
 	    gp_context_progress_stop (context, id);
             return GP_ERROR;
 	}
 
         /* Check for end of data */
-        if ((unsigned char)packet[0] == DC240_SC_COMPLETE) {
+        if (packet[0] == DC240_SC_COMPLETE) {
 	    gp_context_progress_stop (context, id);
             return GP_OK;
 	}
@@ -369,9 +359,9 @@ read_data_read_again:
             goto read_data_read_again;
 
         /* Set size for folder/file list command from 1st packet */
-        if (((unsigned char)cmd_packet[0]==0x99)&&(x==0)) {
-            *size = ((unsigned char)packet[1] * 256 +
-                     (unsigned char)packet[2])* 20 + 2;
+        if (cmd_packet && (cmd_packet[0]==0x99) && (x==0)) {
+            *size = (packet[1] * 256 +
+                     packet[2])* 20 + 2;
             t = (float)*size / (float)(block_size);
             num_packets = (int)t;
             if (t - (float)num_packets > 0)
@@ -383,17 +373,15 @@ read_data_read_again:
             num_bytes = *size - ((num_packets-1) * block_size);
         else
             num_bytes = block_size;
-        gp_file_append(file, &packet[1], num_bytes);
+        gp_file_append(file, (char*)&packet[1], num_bytes);
 
         /* Increment packet count, reset retries */
         x++;
         retries = 0;
     }
     gp_context_progress_stop (context, id);
-
     /* Read in command completed */
     dc240_wait_for_completion(camera);
-
     return (GP_OK);
 }
 
@@ -404,7 +392,7 @@ read_data_read_again:
 int dc240_open (Camera *camera)
 {
     int retval = GP_OK;
-    char *p = dc240_packet_new(0x96);
+    unsigned char *p = dc240_packet_new(0x96);
 
     GP_DEBUG ("dc240_open\n");
 
@@ -427,7 +415,7 @@ int dc240_open (Camera *camera)
 
 int dc240_close (Camera *camera, GPContext *context)
 {
-    char *p = dc240_packet_new(0x97);
+    unsigned char *p = dc240_packet_new(0x97);
     int retval, size = -1;
 
     retval = dc240_packet_exchange(camera, NULL, p, NULL, &size, -1, context);
@@ -439,10 +427,10 @@ int dc240_close (Camera *camera, GPContext *context)
 static int dc240_get_file_size (Camera *camera, const char *folder, const char *filename, int thumb, GPContext *context) {
 
     CameraFile *f;
-    char *p1, *p2;
+    unsigned char *p1, *p2;
     int size = 256, offset;
-    long int fsize;
-    const char *fdata;
+    unsigned long int fsize;
+    const unsigned char *fdata;
 
     offset = (thumb? 92:104);
 
@@ -452,11 +440,11 @@ static int dc240_get_file_size (Camera *camera, const char *folder, const char *
     if (dc240_packet_exchange(camera, f, p1, p2, &size, 256, context) < 0)
         size = 0;
     else {
-	gp_file_get_data_and_size (f, &fdata, &fsize);
-        size = ((unsigned char)fdata[offset]   << 24) |
-               ((unsigned char)fdata[offset+1] << 16) |
-               ((unsigned char)fdata[offset+2] << 8 ) |
-               ((unsigned char)fdata[offset+3]);
+	gp_file_get_data_and_size (f, (const char**)&fdata, &fsize);
+        size = (fdata[offset]   << 24) |
+               (fdata[offset+1] << 16) |
+               (fdata[offset+2] << 8 ) |
+               (fdata[offset+3]);
     }
 
     gp_file_free(f);
@@ -469,7 +457,7 @@ static int dc240_get_file_size (Camera *camera, const char *folder, const char *
 int dc240_set_speed (Camera *camera, int speed)
 {
     int retval;
-    char *p = dc240_packet_new(0x41);
+    unsigned char *p = dc240_packet_new(0x41);
     gp_port_settings settings;
 
     GP_DEBUG ("dc240_set_speed\n");
@@ -478,57 +466,55 @@ int dc240_set_speed (Camera *camera, int speed)
 
     switch (speed) {
     case 9600:
-        p[2] = (unsigned char)0x96;
-        p[3] = (unsigned char)0x00;
+        p[2] = 0x96;
+        p[3] = 0x00;
         settings.serial.speed = 9600;
         break;
     case 19200:
-        p[2] = (unsigned char)0x19;
-        p[3] = (unsigned char)0x20;
+        p[2] = 0x19;
+        p[3] = 0x20;
         settings.serial.speed = 19200;
         break;
     case 38400:
-        p[2] = (unsigned char)0x38;
-        p[3] = (unsigned char)0x40;
+        p[2] = 0x38;
+        p[3] = 0x40;
         settings.serial.speed = 38400;
         break;
     case 57600:
-        p[2] = (unsigned char)0x57;
-        p[3] = (unsigned char)0x60;
+        p[2] = 0x57;
+        p[3] = 0x60;
         settings.serial.speed = 57600;
         break;
     case 0: /* Default */
     case 115200:
-        p[2] = (unsigned char)0x11;
-        p[3] = (unsigned char)0x52;
+        p[2] = 0x11;
+        p[3] = 0x52;
         settings.serial.speed = 115200;
         break;
     /* how well supported is 230.4?
     case 230400:
-         p[2] = (unsigned char)0x23;
-         p[3] = (unsigned char)0x04;
+         p[2] = 0x23;
+         p[3] = 0x04;
          settings.serial.speed = 230400;
          break;
     */
     default:
-        return (GP_ERROR);
+        retval = GP_ERROR;
+	goto fail;
     }
 
     retval = dc240_packet_write(camera, p, 8, 1);
-    if (retval != GP_OK) {
+    if (retval != GP_OK)
 	goto fail;
-    }
 
     retval = gp_port_set_settings (camera->port, settings);
-    if (retval != GP_OK) {
+    if (retval != GP_OK)
         goto fail;
-    }
 
     GP_SYSTEM_SLEEP(300);
     retval = dc240_wait_for_completion(camera);
-    if (retval != GP_OK) {
+    if (retval != GP_OK)
 	goto fail;
-    }
     /* Speed change went OK. */
  fail:
     free (p);
@@ -554,9 +540,8 @@ const char *dc240_convert_type_to_camera (uint16_t type)
     int i = 0;
 
     while (type_to_camera[i].status_type != 0) {
-	if (type_to_camera[i].status_type == type) {
+	if (type_to_camera[i].status_type == type)
 	    return type_to_camera[i].name;
-	}
 	i++;
     }
     /* not found */
@@ -601,31 +586,23 @@ const char * dc240_get_memcard_status_str(uint8_t status)
 {
     if (status & 0x80) {
 	if ((status & 0x10) == 0) {
-	    if (status & 0x08) {
+	    if (status & 0x08)
 		return _("Card is open");
-	    }
-	    else {
-		return _("Card is not open");
-	    }
-	}
-	else {
-	    return _("Card is not formatted");
+	    return _("Card is not open");
 	}
+	return _("Card is not formatted");
     }
-    else {
-	return _("No card");
-    }
+    return _("No card");
 }
 
 
 /*
   Feed manually the stucture from data.
  */
-static int dc240_load_status_data_to_table (const uint8_t *fdata, DC240StatusTable *table)
+static int dc240_load_status_data_to_table (const unsigned char *fdata, DC240StatusTable *table)
 {
-    if (fdata [0] != 0x01) {
+    if (fdata [0] != 0x01)
 	return GP_ERROR;
-    }
     GP_DEBUG ("Camera Type = %d, %s\n", fdata[1], dc240_convert_type_to_camera (fdata[1]));
     table->cameraType = fdata[1];
     table->fwVersInt = fdata[2];
@@ -642,9 +619,9 @@ static int dc240_load_status_data_to_table (const uint8_t *fdata, DC240StatusTab
     table->videoFormat = fdata[12];
     table->quickViewMode = fdata[13]; /* DC280 */
     table->numPict = be16atoh(&fdata[14]);
-    strncpy (table->volumeID, &fdata[16], 11);
+    strncpy (table->volumeID, (char*)&fdata[16], 11);
     table->powerSave = fdata[27]; /* DC280 */
-    strncpy (table->cameraID, &fdata[28], 32);
+    strncpy (table->cameraID, (char*)&fdata[28], 32);
     table->remPictLow = be16atoh(&fdata[60]);
     table->remPictMed = be16atoh(&fdata[62]);
     table->remPictHigh = be16atoh(&fdata[64]);
@@ -678,7 +655,7 @@ static int dc240_load_status_data_to_table (const uint8_t *fdata, DC240StatusTab
     table->fValue = (fdata[136] * 100) + (fdata[137]);
     table->imageEffect = fdata[138];
     table->dateTimeStamp = fdata[139];
-    strncpy (table->borderFileName, &fdata[140], 11);
+    strncpy (table->borderFileName, (char*)&fdata[140], 11);
     table->exposureLock = fdata[152];
     table->isoMode = fdata[153]; /* DC280 */
 
@@ -692,10 +669,10 @@ static int dc240_load_status_data_to_table (const uint8_t *fdata, DC240StatusTab
 int dc240_get_status (Camera *camera, DC240StatusTable *table, GPContext *context)
 {
     CameraFile *file;
-    char *p = dc240_packet_new(0x7F);
+    unsigned char *p = dc240_packet_new(0x7F);
     int retval;
     const char *fdata;
-    long int fsize;
+    unsigned long int fsize;
     int size = 256;
 
     gp_file_new (&file);
@@ -705,7 +682,7 @@ int dc240_get_status (Camera *camera, DC240StatusTable *table, GPContext *contex
     if (retval == GP_OK) {
 	gp_file_get_data_and_size (file, &fdata, &fsize);
 	if (fsize != 256) {
-	    GP_DEBUG ("wrong status packet size ! Size is %d", fsize);
+	    GP_DEBUG ("wrong status packet size ! Size is %ld", fsize);
 	}
 	if (fdata [0] != 0x01) { /* see 2.6 for why 0x01 */
 	    GP_DEBUG ("not a status table. Is %d", fdata [0]);
@@ -719,16 +696,16 @@ int dc240_get_status (Camera *camera, DC240StatusTable *table, GPContext *contex
     return (retval);
 }
 
-static int dc240_get_directory_list (Camera *camera, CameraList *list, const char *folder,
+int dc240_get_directory_list (Camera *camera, CameraList *list, const char *folder,
                              unsigned char attrib, GPContext *context) {
 
     CameraFile *file;
     int x, y=0, z, size=256;
     char buf[64];
-    char *p1 = dc240_packet_new(0x99);
-    char *p2 = dc240_packet_new_path(folder, NULL);
+    unsigned char *p1 = dc240_packet_new(0x99);
+    unsigned char *p2 = dc240_packet_new_path(folder, NULL);
     const char *fdata;
-    long int fsize;
+    unsigned long int fsize;
     int ret;
     int num_of_entries = 0; /* number of entries in the listing */
     int total_size = 0; /* total useful size of the listing */
@@ -736,6 +713,7 @@ static int dc240_get_directory_list (Camera *camera, CameraList *list, const cha
     gp_file_new(&file);
     ret = dc240_packet_exchange(camera, file, p1, p2, &size, 256, context);
     if (ret < 0) {
+	gp_file_free (file);
         return ret;
     }
     free(p1);
@@ -748,7 +726,7 @@ static int dc240_get_directory_list (Camera *camera, CameraList *list, const cha
     /* Conversion below should be endian neutral. */
     num_of_entries = be16atoh(&fdata [0]) + 1;
     total_size = 2 + (num_of_entries * 20);
-    GP_DEBUG ("number of file entries : %d, size = %d", num_of_entries, fsize);
+    GP_DEBUG ("number of file entries : %d, size = %ld", num_of_entries, fsize);
     for (x = 2; x < total_size; x += 20) {
         if ((fdata[x] != '.') && (attrib == (unsigned char)fdata[x+11]))  {
             /* Files have attrib 0x00, Folders have attrib 0x10 */
@@ -770,29 +748,15 @@ static int dc240_get_directory_list (Camera *camera, CameraList *list, const cha
             y++;
         }
     }
-
     gp_file_free(file);
-
     return (GP_OK);
 }
 
-int dc240_get_folders (Camera *camera, CameraList *list, const char *folder,
-		       GPContext *context) {
-
-    return (dc240_get_directory_list(camera, list, folder, 0x10, context));
-}
-
-int dc240_get_filenames (Camera *camera, CameraList *list, const char *folder,
-			 GPContext *context) {
-
-    return (dc240_get_directory_list(camera, list, folder, 0x00, context));
-}
-
 int dc240_file_action (Camera *camera, int action, CameraFile *file,
                        const char *folder, const char *filename, GPContext *context) {
 
     int size=0, thumb=0, retval=GP_OK;
-    char *cmd_packet, *path_packet;
+    unsigned char *cmd_packet, *path_packet;
 
     cmd_packet  = dc240_packet_new(action);
     path_packet = dc240_packet_new_path(folder, filename);
@@ -814,17 +778,16 @@ int dc240_file_action (Camera *camera, int action, CameraFile *file,
         retval = dc240_packet_exchange(camera, file, cmd_packet, path_packet, &size, -1, context);
         break;
     default:
+        free(cmd_packet);
+        free(path_packet);
         return (GP_ERROR);
     }
 
     free(cmd_packet);
     free(path_packet);
 
-    if ((filename) && (file)) {
-	gp_file_set_name (file, filename);
+    if (file)
 	gp_file_set_mime_type (file, GP_MIME_JPEG);
-    }
-
     return (retval);
 }
 
@@ -839,9 +802,9 @@ int dc240_capture (Camera *camera, CameraFilePath *path, GPContext *context)
     CameraFile *file;
     int size = 256;
     int ret = GP_OK;
-    char *p = dc240_packet_new(0x7C);
+    unsigned char *p = dc240_packet_new(0x7C);
     const char *fdata;
-    long int fsize;
+    unsigned long int fsize;
 
     /* Take the picture to Flash memory */
     ret = dc240_packet_write(camera, p, 8, 1);
@@ -892,7 +855,7 @@ int dc240_capture (Camera *camera, CameraFilePath *path, GPContext *context)
 
 int dc240_packet_set_size (Camera *camera, short int size) {
 
-    char *p = dc240_packet_new(0x2A);
+    unsigned char *p = dc240_packet_new(0x2A);
 
     p[2] = (size >> 8) & 0xFF;
     p[3] = (size     ) & 0xFF;
@@ -902,10 +865,6 @@ int dc240_packet_set_size (Camera *camera, short int size) {
 
     if (dc240_wait_for_completion(camera)==GP_ERROR)
             return (GP_ERROR);
-
     free(p);
-
     return (GP_OK);
 }
-
-
