@@ -27,8 +27,8 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <gphoto2-library.h>
-#include <gphoto2-result.h>
+#include <gphoto2/gphoto2-library.h>
+#include <gphoto2/gphoto2-result.h>
 
 #ifdef ENABLE_NLS
 #  include <libintl.h>
@@ -139,8 +139,8 @@ decomp_dct(
 			break;
 		case 0xc0: /* Set 1 value in DCT, 9 bit */
 			xinp=((input[inpos+0]&0x1f)<<7)|(input[inpos+1]&0x7f);
-			if (xinp & 0x0800) 
-				xinp |= 0xff00;	
+			if (xinp & 0x0800)
+				xinp |= 0xff00;
 			curinflags = input[inpos+1] & 0xc0;
 			outtable[outpos] = xinp;
 			outpos++;
@@ -370,7 +370,7 @@ _decompressor(
 	var150 = malloc(edi * esi);
 	if (!var150) return 0;
 	goto 100113f3;
-	
+
 100112af:
 	if (cx <= bp) goto 10011262;
 100112b4:
@@ -503,7 +503,7 @@ _10001889(this) {
 	var3c = -3;
 	ebx = ecx - 5;
 	var2c = -5;
-	var88 = ecx+1; 
+	var88 = ecx+1;
 	var34 = 1;
 	vara0 = ecx-2;
 	var24 = -2;
@@ -697,7 +697,7 @@ _xdecomp(arg0, arg4, arg8, argc, arg10, arg14) {
 			xpixels++;
 			while (ypixels < 160) {
 				switch (ycnt % 11) {
-				case 1: case 3: case 5: case 7: case 9: 
+				case 1: case 3: case 5: case 7: case 9:
 					ypixels++;
 					memcpy(outdata, tmpdata, 3);
 					outdata += 3;
@@ -782,46 +782,6 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	gp_file_append(file, xdata, picsize);
 	free(xdata);
 	gp_file_set_mime_type (file, GP_MIME_UNKNOWN);
-	gp_file_set_name (file, filename);
-	return (GP_OK);
-}
-
-static int
-put_file_func (CameraFilesystem *fs, const char *folder, CameraFile *file,
-	       void *data, GPContext *context)
-{
-	/* Camera *camera; */
-
-	/*
-	 * Upload the file to the camera. Use gp_file_get_data_and_size,
-	 * gp_file_get_name, etc.
-	 */
-
-	return (GP_OK);
-}
-
-static int
-delete_file_func (CameraFilesystem *fs, const char *folder,
-		  const char *filename, void *data, GPContext *context)
-{
-	/* Camera *camera = data; */
-
-	/* Delete the file from the camera. */
-
-	return (GP_OK);
-}
-
-static int
-delete_all_func (CameraFilesystem *fs, const char *folder, void *data,
-		 GPContext *context)
-{
-	/* Camera *camera = data; */
-
-	/*
-	 * Delete all files in the given folder. If your camera doesn't have
-	 * such a functionality, just don't implement this function.
-	 */
-
 	return (GP_OK);
 }
 
@@ -916,39 +876,6 @@ camera_about (Camera *camera, CameraText *about, GPContext *context)
 	return (GP_OK);
 }
 
-static int
-get_info_func (CameraFilesystem *fs, const char *folder, const char *filename,
-	       CameraFileInfo *info, void *data, GPContext *context)
-{
-	/* Camera *camera = data; */
-
-	/* Get the file info here and write it into <info> */
-
-	return (GP_OK);
-}
-static int
-set_info_func (CameraFilesystem *fs, const char *folder, const char *file,
-	       CameraFileInfo info, void *data, GPContext *context)
-{
-	/* Camera *camera = data; */
-
-	/* Set the file info here from <info> */
-
-	return (GP_OK);
-}
-
-
-static int
-folder_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
-		  void *data, GPContext *context)
-{
-	/* Camera *camera = data; */
-
-	/* List your folders here */
-
-	return (GP_OK);
-}
-
 static int
 file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 		void *data, GPContext *context)
@@ -957,20 +884,21 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 	CameraFileInfo  info;
 	unsigned char reply[6];
 	int i, numpics, ret;
+	char fn[20];
 
 	numpics = _get_number_images(camera);
 	if (numpics < GP_OK)
 		return numpics;
-	//gp_list_populate (list, "blink%03i.raw", numpics);
+	/* gp_list_populate (list, "blink%03i.raw", numpics); */
 #if 1
 	for (i=0;i<numpics;i++) {
 		/* we also get the fs info for free, so just set it */
-		info.file.fields = GP_FILE_INFO_TYPE | GP_FILE_INFO_NAME | 
-				GP_FILE_INFO_WIDTH | GP_FILE_INFO_HEIGHT | 
+		info.file.fields = GP_FILE_INFO_TYPE |
+				GP_FILE_INFO_WIDTH | GP_FILE_INFO_HEIGHT |
 				GP_FILE_INFO_SIZE;
 		strcpy(info.file.type,GP_MIME_UNKNOWN);
-		sprintf(info.file.name,"blink%03i.raw",i);
-		ret = gp_filesystem_append(fs, "/", info.file.name, context);
+		sprintf(fn,"blink%03i.raw",i);
+		ret = gp_filesystem_append(fs, "/", fn, context);
 		if (ret != GP_OK)
 			return ret;
 		do {
@@ -985,23 +913,23 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 			info.file.height	= 480;
 			break;
 		case 1:	/* CIF */
-			info.file.width		= 352;	
+			info.file.width		= 352;
 			info.file.height	= 288;
 			break;
 		case 2:	/* QCIF */
-			info.file.width		= 176;	
+			info.file.width		= 176;
 			info.file.height	= 144;
 			break;
 		case 3:	/* QVGA */
-			info.file.width		= 320;	
+			info.file.width		= 320;
 			info.file.height	= 240;
 			break;
 		case 4:	/* ? */
-			info.file.width		= 800;	
+			info.file.width		= 800;
 			info.file.height	= 592;
 			break;
 		case 5:	/* VGA/4 */
-			info.file.width		= 160;	
+			info.file.width		= 160;
 			info.file.height	= 120;
 			break;
 		default:
@@ -1020,6 +948,11 @@ file_list_func (CameraFilesystem *fs, const char *folder, CameraList *list,
 	return (GP_OK);
 }
 
+static CameraFilesystemFuncs fsfuncs = {
+	.file_list_func = file_list_func,
+	.get_file_func = get_file_func,
+};
+
 int
 camera_init (Camera *camera, GPContext *context)
 {
@@ -1039,15 +972,7 @@ camera_init (Camera *camera, GPContext *context)
 	camera->functions->about                = camera_about;
 
 	/* Now, tell the filesystem where to get lists, files and info */
-	gp_filesystem_set_list_funcs (camera->fs, file_list_func,
-				      folder_list_func, camera);
-	gp_filesystem_set_info_funcs (camera->fs, get_info_func, set_info_func,
-				      camera);
-	gp_filesystem_set_file_funcs (camera->fs, get_file_func,
-				      delete_file_func, camera);
-	gp_filesystem_set_folder_funcs (camera->fs, put_file_func,
-					delete_all_func, NULL, NULL, camera);
-
+	gp_filesystem_set_funcs (camera->fs, &fsfuncs, camera);
 	/*
 	 * The port is already provided with camera->port (and
 	 * already open). You just have to use functions like
