@@ -117,7 +117,7 @@ static int stv0680_cmd(GPPort *port, unsigned char cmd,
 	return GP_OK;
 }
 
-static int stv0680_try_cmd(GPPort *port, unsigned char cmd,
+int stv0680_try_cmd(GPPort *port, unsigned char cmd,
 		unsigned short data,
 		unsigned char *response, unsigned char response_len
 ) {
@@ -493,8 +493,10 @@ int stv0680_capture_preview(GPPort *port, char **data, int *size)
 		break;
 	default:break;
 	}
-	if ((ret = stv0680_try_cmd(port, CMDID_STOP_VIDEO, 0, NULL, 0)!=GP_OK))
+	if ((ret = stv0680_try_cmd(port, CMDID_STOP_VIDEO, 0, NULL, 0)!=GP_OK)) {
+		free (raw);
 		return ret;
+	}
 	sprintf(header, "P6\n# gPhoto2 stv0680 image\n%d %d\n255\n", w, h);
 	*data = malloc((*size * 3) + strlen(header));
 	strcpy(*data, header);
@@ -521,7 +523,7 @@ int stv0680_summary(GPPort *port, char *txt)
     struct stv680_image_info imginfo;
     int ret;
 
-    strcpy(txt,_("Information for STV0680 based camera:\n"));
+    strcpy(txt,_("Information on STV0680-based camera:\n"));
     /* Get Camera Information */
     if ((ret = stv0680_try_cmd(port, CMDID_GET_CAMERA_INFO,
 				0, (void*)&caminfo, sizeof(caminfo)) < 0))
@@ -540,7 +542,7 @@ int stv0680_summary(GPPort *port, char *txt)
     );
     /* HWCONFIG_COMMSLINK_MASK ... not really needed, the user knows, he
      * plugged it in. */
-    sprintf(txt+strlen(txt),_("Camera is configured for lights flickering with %dHz.\n"),
+    sprintf(txt+strlen(txt),_("Camera is configured for lights flickering by %dHz.\n"),
     	(caminfo.hardware_config & HWCONFIG_FLICKERFREQ_60HZ)?60:50
     );
     sprintf(txt+strlen(txt),_("Memory in camera: %d Mbit.\n"),
